'use strict';

var postcss = require('postcss');

var LOCAL_ENCAPSULATION_PATTERN = /:local\(([^)]+)\)/g;
var SELECTOR_PATTERN = /[-_.#]+([a-zA-Z])/g;

var firstLetterOfWordReplacer = function firstLetterOfWordReplacer(string, character) {
  switch (string[0]) {
    case '.':
      return '.' + character.toLowerCase();

    case '#':
      return '#' + character.toLowerCase();

    default:
      return '' + character.toUpperCase();
  }
};

var camelCaser = function camelCaser(rule) {
  rule.selector = rule.selector.replace(LOCAL_ENCAPSULATION_PATTERN, function (a, match) {
    return ':local(' + match.replace(SELECTOR_PATTERN, firstLetterOfWordReplacer) + ')';
  });

  return rule;
};

module.exports = {
  camelCaser: camelCaser,
  default: postcss.plugin('postcss-camelcaser', function () {
    return function (css) {
      css.walkRules(camelCaser);
    };
  }),
  firstLetterOfWordReplacer: firstLetterOfWordReplacer
};