'use strict';

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var fs = require('fs');
var path = require('path');

var autoprefixer = require('autoprefixer');
var cssnano = require('cssnano');
var postcss = require('postcss');
var sass = require('node-sass');
var uuid = require('node-uuid');

var Core = require('css-modules-loader-core');
var camelCaser = require('./transform/camelCaser').default;

var core = new Core([Core.localByDefault, Core.extractImports, camelCaser, Core.scope]);

/**
 * transform the source into autoprefixed css and save it to the target
 *
 * @param {string} target
 * @param {string} hash
 * @param {string} source
 * @returns {Promise}
 */
var transformStyles = function transformStyles(_ref) {
  var _ref$hash = _ref.hash,
      hash = _ref$hash === undefined ? uuid.v4() : _ref$hash,
      _ref$minify = _ref.minify,
      minify = _ref$minify === undefined ? true : _ref$minify,
      source = _ref.source,
      target = _ref.target;

  if (!source) {
    throw new Error('source file location was not provided');
  }

  if (!target) {
    throw new Error('target file location was not provided');
  }

  var sourceFileExtension = source.split('.').slice(-1)[0];

  var renderedFile = void 0;

  if (sourceFileExtension === 'scss') {
    // if the file is SCSS, use node-sass to compile into a Buffer
    renderedFile = sass.renderSync({
      file: source,
      importer: function importer(url) {
        if (url[0] === '~') {
          url = path.resolve(path.dirname(require.main.filename), 'node_modules', url.substring(1));
        }

        return {
          file: url
        };
      }
    }).css;
  } else {
    // otherwise, read the file as a Buffer
    renderedFile = fs.readFileSync(source, 'utf8');
  }

  // convert the Buffer to a string and prefix via postcss
  var string = renderedFile.toString('utf8');

  var prefixerPlugins = [autoprefixer({
    remove: false
  })];

  if (minify) {
    prefixerPlugins = [].concat(_toConsumableArray(prefixerPlugins), [cssnano]);
  }

  var prefixer = postcss(prefixerPlugins);

  return prefixer.process(string).then(function (_ref2) {
    var css = _ref2.css;

    // load the prefixed CSS and convert via CSS Modules, then create a file with all metadata provided
    return core.load(css, hash).then(function (_ref3) {
      var exportTokens = _ref3.exportTokens,
          injectableSource = _ref3.injectableSource;

      // provide the compiled CSS, the id to use in the style tag, and the selector map
      var fileValue = {
        css: injectableSource,
        id: hash + '_Scoped_Styles',
        selectors: exportTokens
      };

      // clean the string to mean the rapid7 ESLint config rules
      var bufferString = JSON.stringify(fileValue).replace(/'/g, '\\\'').replace(/"/g, '\'').replace(/,/g, ', ');

      // make a Buffer of an exportable file
      var buffer = new Buffer('module.exports = ' + bufferString + ';\n');

      // write the file to the target
      fs.writeFileSync(target, buffer);

      return fileValue;
    });
  });
};

module.exports = transformStyles;